@@ -1,6 +1,6 @@
 package Bencher::ScenarioR::NormalRandom;
 
-our $VERSION = 0.001; # VERSION
+our $VERSION = 0.002; # VERSION
 
 our $results = [
   [
@@ -8,28 +8,28 @@ our $results = [
     "OK",
     [
       {
-        errors => 1.1e-06,
+        errors => 1.8e-06,
         participant => "Math::Random::OO::Normal",
-        rate => 374,
+        rate => 345,
         samples => 20,
-        time => 2.68,
+        time => 2.9,
         vs_slowest => 1,
       },
       {
-        errors => 9.6e-07,
+        errors => 9.1e-07,
         participant => "Math::Random::GaussianRange",
-        rate => 1400,
+        rate => 1300,
         samples => 20,
-        time => 0.69,
-        vs_slowest => 3.9,
+        time => 0.77,
+        vs_slowest => 3.8,
       },
       {
         errors => 2.1e-07,
         participant => "Math::Random::NormalDistribution",
-        rate => 2430,
+        rate => 2260,
         samples => 20,
-        time => 0.411,
-        vs_slowest => 6.51,
+        time => 0.442,
+        vs_slowest => 6.56,
       },
     ],
     {
@@ -154,7 +154,7 @@ our $results = [
                                               number_of_cores              => 2,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 0,
-                                              speed                        => 2704.895,
+                                              speed                        => 2599.877,
                                               stepping                     => 4,
                                             },
                                             {
@@ -270,7 +270,7 @@ our $results = [
                                               number_of_cores              => 2,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 1,
-                                              speed                        => 2728.906,
+                                              speed                        => 2599.108,
                                               stepping                     => 4,
                                             },
                                             {
@@ -386,7 +386,7 @@ our $results = [
                                               number_of_cores              => 2,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 2,
-                                              speed                        => 2485.375,
+                                              speed                        => 2596.972,
                                               stepping                     => 4,
                                             },
                                             {
@@ -502,11 +502,11 @@ our $results = [
                                               number_of_cores              => 2,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 3,
-                                              speed                        => 2397.961,
+                                              speed                        => 2607.141,
                                               stepping                     => 4,
                                             },
                                           ],
-      "func.elapsed_time"              => 0.175851106643677,
+      "func.elapsed_time"              => 0.222904920578003,
       "func.module_startup"            => undef,
       "func.module_versions"           => {
                                             "__PACKAGE__" => 1.041,
@@ -546,13 +546,13 @@ our $results = [
                                           },
       "func.precision"                 => 0,
       "func.scenario_module"           => "Bencher::Scenario::NormalRandom",
-      "func.scenario_module_md5sum"    => "691bceb13ba7a003e85598f0648740fe",
-      "func.scenario_module_mtime"     => 1535463022,
-      "func.scenario_module_sha1sum"   => "d87688676fe50bbffba5337d90267701d6a1cd7e",
-      "func.scenario_module_sha256sum" => "6b7ef42a4e2a09f71cce893fead29fe1b8bb3832fad9f9204649dacf80f670a9",
-      "func.time_end"                  => 1535858720.57534,
+      "func.scenario_module_md5sum"    => "1bf245acfcb3bef36268576084dfcfa9",
+      "func.scenario_module_mtime"     => 1535984198,
+      "func.scenario_module_sha1sum"   => "122100af03524201dab0f4e5dffa12cb05ba50c2",
+      "func.scenario_module_sha256sum" => "c2257a56ea35227710ec5bdf45e0ff46d18913602d3e411e7fed19bd4bfd5155",
+      "func.time_end"                  => 1535984616.25443,
       "func.time_factor"               => 1000,
-      "func.time_start"                => 1535858720.39948,
+      "func.time_start"                => 1535984616.03153,
       "table.field_aligns"             => ["left", "left", "number", "number", "number", "number", "number"],
       "table.field_units"              => [undef, undef, "/s", "ms"],
       "table.fields"                   => [
@@ -569,7 +569,7 @@ our $results = [
 ];
 
 1;
-# ABSTRACT: Benchmark generating normally distributed normal numbers
+# ABSTRACT: Benchmark generating normally distributed random numbers
 
 =head1 DESCRIPTION
 
